@@ -7,6 +7,11 @@ from Crypto.Hash import SHA512, SHA
 from Crypto.PublicKey import RSA
 from Crypto.Signature import PKCS1_v1_5
 
+parser = argparse.ArgumentParser()
+parser.add_argument("-ip", dest="ip", help="ip", default="192.168.2.251", required=False)
+args = parser.parse_args()
+ip = args.ip
+
 
 class JenkinsUpdateCenter:
     def __init__(self):
@@ -87,7 +92,7 @@ class JenkinsUpdateCenter:
             raise Exception("Could not write output. " + str(err))
 
 
-def main(ip):
+def main():
     www_root = "/YUM/jenkins/"
     original_update_center_json = "update-center.json"
     www_url = f"http://{ip}:81/jenkins"
@@ -119,8 +124,4 @@ def main(ip):
 
 
 if __name__ == '__main__':
-    parser = argparse.ArgumentParser()
-    parser.add_argument("-ip", dest="ip", help="ip", default="192.168.2.251", required=False)
-    args = parser.parse_args()
-    print(args)
-    main(args.ip)
+    main()
